smrf.spatial.dk package
=======================

Submodules
----------

smrf.spatial.dk.detrended\_kriging module
-----------------------------------------

.. automodule:: smrf.spatial.dk.detrended_kriging
   :members:
   :undoc-members:
   :show-inheritance:

smrf.spatial.dk.detrended\_kriging module
-----------------------------------------

.. automodule:: smrf.spatial.dk.detrended_kriging
   :members:
   :undoc-members:
   :show-inheritance:

smrf.spatial.dk.dk module
-------------------------

.. automodule:: smrf.spatial.dk.dk
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: smrf.spatial.dk
   :members:
   :undoc-members:
   :show-inheritance:
